@@ -711,14 +711,14 @@ def agent(
         envvar=f"{PREFIX}_BIND_PORT",
         show_envvar=False,
     ),
-    # enable_registrar: bool = typer.Option(
-    #     False,
-    #     "--registrar",
-    #     "-s",
-    #     envvar=f"{PREFIX}_REGISTRAR",
-    #     show_envvar=False,
-    #     help="Act as a proxy registrar for other agents",
-    # ),
+    disable_webserver: bool = typer.Option(
+        False,
+        "--disable-webserver",
+        "-s",
+        envvar=f"{PREFIX}_DISABLE_WEBSERVER",
+        show_envvar=False,
+        help="Disable local http webserver (registrar and fileserver)",
+    ),
     registrar_port: int = typer.Option(
         "2080",
         "--registrar-port",
@@ -827,6 +827,7 @@ def agent(
         bind_address=bind_address,
         bind_port=bind_port,
         registrar=registrar,
+        disable_webserver=disable_webserver,
         primary_agent=primary_agent,
         whitelisted_addresses=whitelisted_addresses,
         verify_source_address=verify_source_address,
